# This file was auto-generated by Fern from our API Definition.

from ..core.pydantic_utilities import UniversalBaseModel
import typing
from .legacy_guideline_connection_addition import LegacyGuidelineConnectionAddition
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class LegacyGuidelineConnectionUpdateParams(UniversalBaseModel):
    """
    Parameters for updating a guideline connection.

    `add` is expected to be a collection of addition objects.
    `remove` should contain the `id`s of the guidelines to remove.
    """

    add: typing.Optional[typing.List[LegacyGuidelineConnectionAddition]] = None
    remove: typing.Optional[typing.List[str]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(
            extra="allow", frozen=True
        )  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
